@@ -4,6 +4,7 @@ pub mod macros {
     /// as_to!() can be used to
     /// convert type
     /// ```rust
+    /// use useful_macro::*;
     ///  let s = as_to!(5., i64);
     ///  assert_eq!(5, s);
     /// ```
@@ -83,6 +84,7 @@ pub mod macros {
     /// powf!(a,b) can be used to
     /// a to the power of b
     /// ```rust
+    /// use useful_macro::*;
     /// let p = powf!(2.,2.);
     /// assert_eq!(p,4.0);
     /// ```
@@ -94,7 +96,8 @@ pub mod macros {
     }
     /// arg!() can be used to
     ///get argument and collect to Vec\<String\>
-    /// ```rust
+    /// ```ignore
+    /// use useful_macro::*;
     /// //cargo run -- -n 100
     /// let arg = args!();
     /// assert_eq!(arg,vec![format!("-n"),format!("100")]);
@@ -108,6 +111,7 @@ pub mod macros {
     /// input!() can be used to
     /// get user input from terminal
     /// ```rust
+    /// use useful_macro::*;
     /// let s = input!();
     /// println!("{:?}",s);
     /// ```
@@ -123,6 +127,7 @@ pub mod macros {
     /// split_to_vec!() can be used to
     /// a:&str split by b:&str and collect to Vec\<String\>
     /// ```rust
+    /// use useful_macro::*;
     /// let s = split_to_vec!("aa.bb",".");
     /// assert_eq!(s,vec![format!("aa"),format!("bb")]);
     /// ```
@@ -139,6 +144,7 @@ pub mod macros {
     /// read_csv!() can be used to
     /// read .csv file and return Vec\<Vec\<String\>\>
     /// ```rust
+    /// use useful_macro::*;
     ///let s = read_csv!("./data.csv");
     ///assert_eq!(s,vec![vec![format!("a"), format!("b"), format!("c")],vec![format!("1"), format!("2"), format!("3")],vec![format!("10"), format!("20"), format!("30")]]);
     /// ```
@@ -158,6 +164,7 @@ pub mod macros {
     /// return sorted new Vec,
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>   
     /// ```rust
+    /// use useful_macro::*;
     /// let s1 = sorted!(vec![1.2, 2.6, 0.2]);
     /// let s2 = sorted!(vec![8, 1_i128, 5_i128]);
     /// assert_eq!(s1,vec![0.2,1.2,2.6]);
@@ -175,8 +182,9 @@ pub mod macros {
     /// return sorted and deduped new Vec,
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>   
     /// ```rust
+    /// use useful_macro::*;
     /// let s1 = deduped_sorted!(vec![1.2, 1.2,2.6, 0.2]);
-    /// let s2 = deduped_sorted!(vec![8, 1_i128, ,8,5_i128]);
+    /// let s2 = deduped_sorted!(vec![8, 1_i128,8,5_i128]);
     /// assert_eq!(s1,vec![0.2,1.2,2.6]);
     /// assert_eq!(s2,vec![1,5,8]);
     /// ```
@@ -194,6 +202,7 @@ pub mod macros {
     /// type can be Vec\<&str\>
     /// return Vec\<f64\>
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_parse!(vec!["15.", "2.9"]);
     ///let v2 = vec_element_parse!(vec!["15", "2"]);
     ///let v3 = vec_element_parse!(vec![".15", ".2"]);
@@ -225,6 +234,7 @@ pub mod macros {
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
     /// return Vec\<String\>
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_to_string!(vec!["15.", "2.9"]);
     ///let v2 = vec_element_to_string!(vec![15, 2]);
     ///let v3 = vec_element_to_string!(vec![0.15, 0.2]);
@@ -251,6 +261,7 @@ pub mod macros {
     /// type can be Vec\<Vec\<T\>\>
     /// return Vec\<T\>
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = snail_sort!(vec![vec![1, 2, 3], vec![4, 5, 6], vec![7, 8, 9]]);
     ///let v2 =  snail_sort!(vec![vec![1.1, 2.1, 3.1],vec![4.1, 5.1, 6.1],vec![7.1, 8.1, 9.1]]);
     ///assert_eq!(vec![1, 2, 3, 6, 9, 8, 7, 4, 5], v1);
@@ -295,6 +306,7 @@ pub mod macros {
     /// take two matrix and type can be Vec\<Vec\<f64\>\>
     /// return Vec\<f64\>
     /// ```rust
+    /// use useful_macro::*;
     ///let m1: Vec<Vec<f64>> = vec![vec![1.0, 2.0], vec![1.0, 2.0]];
     ///let m2: Vec<Vec<f64>> = vec![vec![0.0, 0.0], vec![0.0, 0.5]];
     ///let mul_result = multiply_matrix!(&m2, &m1);
@@ -339,6 +351,7 @@ pub mod macros {
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
     /// return return the same type
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_remove!(vec!["15.", "2.9"], "2.9");
     ///let v2 = vec_element_remove!(vec![15, 2, 3, 2], 2);
     ///let v3 = vec_element_remove!(vec![0.15, 0.2, 0.2], 0.2);
@@ -365,6 +378,7 @@ pub mod macros {
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
     /// return return the same type
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_remove_all!(vec!["15.", "2.9", "0.9", "2.9", "2.9"], "2.9");
     ///assert_eq!(vec!["15.", "0.9"], v1);
     ///let v2 = vec_element_remove_all!(vec![15, 2, 3, 2], 2);
@@ -393,6 +407,7 @@ pub mod macros {
     }
     /// vec_element_position_all!() used to find element position and collect into Vec<usize>
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_position_all!(vec![1, 2, 5, 3, 6, 2, 2], 2);
     ///assert_eq!(v1, vec![1, 5, 6]);
     /// ```
@@ -414,16 +429,17 @@ pub mod macros {
         };};
     }
 
-    /// slice_vec!() used to
+    /// vec_slice!() used to
     /// slice vec by range
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
     /// return return the same type
     /// ```rust
-    ///let v1 = slice_vec!(vec![1.2, 1.5, 9.0], [..2]);
-    ///let v2 = slice_vec!(vec![1, 1, 9, 90, 87, 0, 2], [4..6]);
-    ///let v3 = slice_vec!(vec![1.2, 1.5, 9.0], [..]);
-    ///let v4 = slice_vec!(vec![1.2, 1.5, 9.0], [1..]);
-    ///let v5 = slice_vec!(vec!["1", "2", "3", "4", "5"], [2..5]);
+    /// use useful_macro::*;
+    ///let v1 = vec_slice!(vec![1.2, 1.5, 9.0], [..2]);
+    ///let v2 = vec_slice!(vec![1, 1, 9, 90, 87, 0, 2], [4..6]);
+    ///let v3 = vec_slice!(vec![1.2, 1.5, 9.0], [..]);
+    ///let v4 = vec_slice!(vec![1.2, 1.5, 9.0], [1..]);
+    ///let v5 = vec_slice!(vec!["1", "2", "3", "4", "5"], [2..5]);
     ///assert_eq!(v1, vec![1.2, 1.5]);
     ///assert_eq!(v2, vec![87, 0]);
     ///assert_eq!(v3, vec![1.2, 1.5, 9.0]);
@@ -431,7 +447,7 @@ pub mod macros {
     ///assert_eq!(v5, vec!["3", "4", "5"]);
     /// ```
     #[macro_export]
-    macro_rules! slice_vec {
+    macro_rules! vec_slice {
         ($vec:expr,$slice:expr) => {{
             let mut vec = $vec.clone();
             let slice = $slice.clone();
@@ -481,6 +497,7 @@ pub mod macros {
     /// cannot move out of index of `Vec<String>`
     /// move occurs because value has type `String`, which does not implement the `Copy` trait
     /// ```rust
+    /// use useful_macro::*;
     ///let v1 = vec_element_clone!(vec!["15.", "2.9"], 1);
     ///let v2 = vec_element_clone!(vec![15, 2, 3, 2], 2);
     ///let v3 = vec_element_clone!(vec![0.15, 0.2, 0.2], 0);
@@ -499,10 +516,9 @@ pub mod macros {
         };};
     }
     /// remove_file_or_folder!() used to remove file or folder
-    /// ```rust
+    /// ```ignore
     ///remove_file_or_folder!("./demo.txt");
     ///remove_file_or_folder!("./target");
-    ///
     /// ```
     #[macro_export]
     macro_rules! remove_file_or_folder {
@@ -520,8 +536,97 @@ pub mod macros {
             rm(path);
         };};
     }
+    /// vec_type!() used to get vec type
+    /// return format!("{}",type);
+    /// ```rust
+    /// use useful_macro::*;
+    ///assert_eq!(vec_type!(vec![0.2_f64]), format!("Vec<f64>"));
+    ///assert_eq!(vec_type!(vec![0.2_f32]), format!("Vec<f32>"));
+    ///assert_eq!(vec_type!(vec![2_i32]), format!("Vec<i32>"));
+    ///assert_eq!(vec_type!(vec![2_i128]), format!("Vec<i128>"));
+    ///assert_eq!(vec_type!(vec![2_isize]), format!("Vec<isize>"));
+    ///assert_eq!(vec_type!(vec![2_usize]), format!("Vec<usize>"));
+    /// ```
+    #[macro_export]
+    macro_rules! vec_type {
+        ($vec:expr) => {{
+            use std::any::Any;
+            pub fn vec_type(s: &dyn Any) -> String {
+                let mut re = String::new();
+                if s.is::<Vec<String>>() {
+                    re = format!("Vec<String>");
+                } else if s.is::<Vec<&str>>() {
+                    re = format!("Vec<&str>");
+                } else if s.is::<Vec<i128>>() {
+                    re = format!("Vec<i128>");
+                } else if s.is::<Vec<i64>>() {
+                    re = format!("Vec<i64>");
+                } else if s.is::<Vec<i32>>() {
+                    re = format!("Vec<i32>");
+                } else if s.is::<Vec<i16>>() {
+                    re = format!("Vec<i16>");
+                } else if s.is::<Vec<i8>>() {
+                    re = format!("Vec<i8>");
+                } else if s.is::<Vec<u128>>() {
+                    re = format!("Vec<u128>");
+                } else if s.is::<Vec<u64>>() {
+                    re = format!("Vec<u64>");
+                } else if s.is::<Vec<u32>>() {
+                    re = format!("Vec<u32>");
+                } else if s.is::<Vec<u16>>() {
+                    re = format!("Vec<u16>");
+                } else if s.is::<Vec<u8>>() {
+                    re = format!("Vec<u8>");
+                } else if s.is::<Vec<f64>>() {
+                    re = format!("Vec<f64>");
+                } else if s.is::<Vec<f32>>() {
+                    re = format!("Vec<f32>");
+                } else if s.is::<Vec<usize>>() {
+                    re = format!("Vec<usize>");
+                } else if s.is::<Vec<isize>>() {
+                    re = format!("Vec<isize>");
+                } else {
+                    re = format!("");
+                }
+                re
+            }
+            vec_type(&$vec)
+        };};
+    }
 
-    pub fn run() {}
+    /// vec_parse!() used to remove file or folder
+    /// ```rust
+    /// use useful_macro::*;
+    ///let v1: Vec<f64> = vec_element_convert!(vec![1, 2], f64);
+    ///let v2: Vec<i32> = vec_element_convert!(vec![1.0, 2.0], i32);
+    ///let v3: Vec<i128> = vec_element_convert!(vec![1.0, 2.0], i128);
+    ///let v4: Vec<i32> = vec_element_convert!(vec![1_usize, 2_usize], i32);
+    ///let v5: Vec<i64> = vec_element_convert!(vec![0.15, 2.0], i64);
+    ///assert_eq!(v1, vec![1.0, 2.0]);
+    ///assert_eq!(v2, vec![1, 2]);
+    ///assert_eq!(v3, vec![1, 2]);
+    ///assert_eq!(v4, vec![1, 2]);
+    ///assert_eq!(v5, vec![0, 2]);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_convert {
+        ($vec:expr,$type:ty) => {{
+            let vec = $vec.clone();
+            let mut re: Vec<$type> = Vec::new();
+            let re_type = vec_type!(re);
+            if vec_type!(re) != format!("Vec<String>") {
+                for item in &vec {
+                    re.push(*item as $type);
+                }
+            }
+
+            re
+        };};
+    }
+
+    pub fn run() {
+        vec_element_convert!(vec![0], f64);
+    }
 }
 
 #[cfg(test)]
